==> jc-1.4.0.tar.gz: ppg/atoms/SymbolList.h <==
// public class ppg.atoms.SymbolList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 972dde525d9affe8 ppg_atoms_SymbolList

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_atoms_SymbolList_H_
#define _JC_ppg_atoms_SymbolList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_ppg_atoms_SymbolList$sub_refs	_jc_ppg_atoms_SymbolList$sub_refs;
typedef struct _jc_ppg_atoms_SymbolList$sub_nonrefs	_jc_ppg_atoms_SymbolList$sub_nonrefs;
typedef struct _jc_ppg_atoms_SymbolList$refs	_jc_ppg_atoms_SymbolList$refs;
typedef struct _jc_ppg_atoms_SymbolList$nonrefs	_jc_ppg_atoms_SymbolList$nonrefs;
typedef struct _jc_ppg_atoms_SymbolList$object	_jc_ppg_atoms_SymbolList$object;

typedef struct _jc_ppg_atoms_SymbolList$fields_struct	_jc_ppg_atoms_SymbolList$fields_struct;
typedef const struct _jc_ppg_atoms_SymbolList$vmethods	_jc_ppg_atoms_SymbolList$vmethods;
typedef const struct _jc_ppg_atoms_SymbolList$vtable	_jc_ppg_atoms_SymbolList$vtable;
typedef const struct _jc_ppg_atoms_SymbolList$vtype	_jc_ppg_atoms_SymbolList$vtype;

// Class fields structure
struct _jc_ppg_atoms_SymbolList$fields_struct {
	jint	NONTERMINAL;
	jint	TERMINAL;
};
extern _jc_ppg_atoms_SymbolList$fields_struct _jc_ppg_atoms_SymbolList$class_fields;

// Constructors
extern void _jc_ppg_atoms_SymbolList$method$_init$8182d69b2ab8d46d(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *, jint, struct _jc_java_lang_String$object *, struct _jc_java_util_Vector$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_SymbolList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *);
extern jboolean _jc_ppg_atoms_SymbolList$method$dropSymbol$afbbff800f64d7b2(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_SymbolList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_SymbolList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_SymbolList$method_info$dropSymbol$afbbff800f64d7b2;
extern _jc_method _jc_ppg_atoms_SymbolList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_atoms_SymbolList$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *);
	jboolean	(*dropSymbol$afbbff800f64d7b2)(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *);
};

// Vtable
struct _jc_ppg_atoms_SymbolList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_SymbolList$vmethods	ppg_atoms_SymbolList;
};

// Vtype
struct _jc_ppg_atoms_SymbolList$vtype {
	_jc_type			type;
	_jc_ppg_atoms_SymbolList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_SymbolList$sub_refs {
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_util_Vector$object	*symbols;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_SymbolList$refs {
    _jc_ppg_atoms_SymbolList$sub_refs	ppg_atoms_SymbolList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_SymbolList$sub_nonrefs {
	jint	variety;
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_SymbolList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_SymbolList$sub_nonrefs	ppg_atoms_SymbolList;
};

// Object instance structure
struct _jc_ppg_atoms_SymbolList$object {
	_jc_ppg_atoms_SymbolList$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_SymbolList$vtype	*vtype;
	_jc_ppg_atoms_SymbolList$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_SymbolList$vtype _jc_ppg_atoms_SymbolList$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_SymbolList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_SymbolList$class_object;

#endif	/* _JC_ppg_atoms_SymbolList_H_ */

==> jc-1.4.6.tar.gz: ppg/atoms/SymbolList.h <==
// public class ppg.atoms.SymbolList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 972dde525d9affe8 ppg_atoms_SymbolList

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_atoms_SymbolList_H_
#define _JC_ppg_atoms_SymbolList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_ppg_atoms_SymbolList$sub_refs	_jc_ppg_atoms_SymbolList$sub_refs;
typedef struct _jc_ppg_atoms_SymbolList$sub_nonrefs	_jc_ppg_atoms_SymbolList$sub_nonrefs;
typedef struct _jc_ppg_atoms_SymbolList$refs	_jc_ppg_atoms_SymbolList$refs;
typedef struct _jc_ppg_atoms_SymbolList$nonrefs	_jc_ppg_atoms_SymbolList$nonrefs;
typedef struct _jc_ppg_atoms_SymbolList$object	_jc_ppg_atoms_SymbolList$object;

typedef struct _jc_ppg_atoms_SymbolList$fields_struct	_jc_ppg_atoms_SymbolList$fields_struct;
typedef const struct _jc_ppg_atoms_SymbolList$vmethods	_jc_ppg_atoms_SymbolList$vmethods;
typedef const struct _jc_ppg_atoms_SymbolList$vtable	_jc_ppg_atoms_SymbolList$vtable;
typedef const struct _jc_ppg_atoms_SymbolList$vtype	_jc_ppg_atoms_SymbolList$vtype;

// Class fields structure
struct _jc_ppg_atoms_SymbolList$fields_struct {
	jint	NONTERMINAL;
	jint	TERMINAL;
};
extern _jc_ppg_atoms_SymbolList$fields_struct _jc_ppg_atoms_SymbolList$class_fields;

// Constructors
extern void _jc_ppg_atoms_SymbolList$method$_init$8182d69b2ab8d46d(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *, jint, struct _jc_java_lang_String$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_SymbolList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *) _JC_JCNI_ATTR;
extern jboolean _jc_ppg_atoms_SymbolList$method$dropSymbol$afbbff800f64d7b2(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_SymbolList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_SymbolList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_SymbolList$method_info$dropSymbol$afbbff800f64d7b2;
extern _jc_method _jc_ppg_atoms_SymbolList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_atoms_SymbolList$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *) _JC_JCNI_ATTR;
	jboolean	(*dropSymbol$afbbff800f64d7b2)(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_SymbolList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_atoms_SymbolList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_SymbolList$vmethods	ppg_atoms_SymbolList;
};

// Vtype
struct _jc_ppg_atoms_SymbolList$vtype {
	_jc_type			type;
	_jc_ppg_atoms_SymbolList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_SymbolList$sub_refs {
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_util_Vector$object	*symbols;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_SymbolList$refs {
    _jc_ppg_atoms_SymbolList$sub_refs	ppg_atoms_SymbolList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_SymbolList$sub_nonrefs {
	jint	variety;
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_SymbolList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_SymbolList$sub_nonrefs	ppg_atoms_SymbolList;
};

// Object instance structure
struct _jc_ppg_atoms_SymbolList$object {
	_jc_ppg_atoms_SymbolList$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_SymbolList$vtype	*vtype;
	_jc_ppg_atoms_SymbolList$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_SymbolList$vtype _jc_ppg_atoms_SymbolList$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_SymbolList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_SymbolList$class_object;

#endif	/* _JC_ppg_atoms_SymbolList_H_ */
